Documentation
¶
Overview ¶
Package icy is a dead simple Icecast transmission library for Go, with support for in-band metadata.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultTitleHandler = icy.DefaultTitleHandler
DefaultTitleHandler is the default function called to determine a song's name/artist from its content/filename.
Functions ¶
func Play ¶
func Play(glob string, radioDetails RadioDetails) (http.Handler, error)
Play returns an http.Handler that streams all files collected by glob indefinitely in order.
func SetTitleHandler ¶
SetTitleHandler changes the function that is called to determine a song's name/artist from its content/filename.
func Shuffle ¶
func Shuffle(glob string, radioDetails RadioDetails) (http.Handler, error)
Shuffle returns an http.Handler that streams all files collected by glob indefinitely in a randomized order.
Types ¶
type RadioDetails ¶
type RadioDetails = icy.RadioDetails
Click to show internal directories.
Click to hide internal directories.